@@ -18,7 +18,7 @@ pCM <- superb(
     adjustments=list(decorrelation="none"),
     preprocessfct = "subjectCenteringTransform",
     postprocessfct = "biasCorrectionTransform",
-    plotStyle = "pointjitter",
+    plotLayout = "pointjitter",
     errorbarParams = list(color="red", width= 0.1, position = position_nudge(-0.05) )
 )
 
@@ -29,7 +29,7 @@ pLM <- superb(
     adjustments=list(decorrelation="none"),
     preprocessfct = "subjectCenteringTransform",
     postprocessfct = c("biasCorrectionTransform","poolSDTransform"),
-    plotStyle = "line",
+    plotLayout = "line",
     errorbarParams = list(color="orange", width= 0.1, position = position_nudge(-0.0) )
 )
 
@@ -40,7 +40,7 @@ pNKM <- superb(
     adjustments=list(decorrelation="none"),
     preprocessfct = "subjectCenteringTransform",
     postprocessfct = c("poolSDTransform"),
-    plotStyle = "line",
+    plotLayout = "line",
     errorbarParams = list(color="blue", width= 0.1, position = position_nudge(+0.05) )
 )
 
